@@ -3,8 +3,9 @@ use warnings;
 
 package Syntax::Feature::Qs;
 
-our $VERSION = '0.2004'; # VERSION
 # ABSTRACT: Trim leading whitespace from all lines in a string
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.2005';
 
 use Devel::Declare 0.006007 ();
 use B::Hooks::EndOfScope 0.09;
@@ -92,9 +93,23 @@ __END__
 
 Syntax::Feature::Qs - Trim leading whitespace from all lines in a string
 
+
+
+=begin html
+
+<p>
+<img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
+<a href="https://travis-ci.org/Csson/p5-Syntax-Feature-Qs"><img src="https://api.travis-ci.org/Csson/p5-Syntax-Feature-Qs.svg?branch=master" alt="Travis status" /></a>
+<a href="http://cpants.cpanauthors.org/release/CSSON/Syntax-Feature-Qs-0.2005"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/Syntax-Feature-Qs/0.2005" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Syntax-Feature-Qs%200.2005"><img src="http://badgedepot.code301.com/badge/cpantesters/Syntax-Feature-Qs/0.2005" alt="CPAN Testers result" /></a>
+<img src="https://img.shields.io/badge/coverage-98.6%-yellow.svg" alt="coverage 98.6%" />
+</p>
+
+=end html
+
 =head1 VERSION
 
-Version 0.2004, released 2015-02-10.
+Version 0.2005, released 2017-01-28.
 
 =head1 SYNOPSIS
 
@@ -156,7 +171,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
